==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/cxf/mime/types/ObjectFactory.java <==

package org.apache.cxf.mime.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.mime.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TestXopResponse_QNAME = new QName("http://cxf.apache.org/mime/types", "testXopResponse");
    private final static QName _TestXop_QNAME = new QName("http://cxf.apache.org/mime/types", "testXop");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.mime.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link XopType }
     * 
     */
    public XopType createXopType() {
        return new XopType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXopResponse")
    public JAXBElement<XopType> createTestXopResponse(XopType value) {
        return new JAXBElement<XopType>(_TestXopResponse_QNAME, XopType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXop")
    public JAXBElement<XopType> createTestXop(XopType value) {
        return new JAXBElement<XopType>(_TestXop_QNAME, XopType.class, null, value);
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/cxf/mime/types/ObjectFactory.java <==

package org.apache.cxf.mime.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.mime.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TestXopStringArgument_QNAME = new QName("http://cxf.apache.org/mime/types", "testXopStringArgument");
    private final static QName _TestXopResponse_QNAME = new QName("http://cxf.apache.org/mime/types", "testXopResponse");
    private final static QName _TestXopStringResponse_QNAME = new QName("http://cxf.apache.org/mime/types", "testXopStringResponse");
    private final static QName _TestXop_QNAME = new QName("http://cxf.apache.org/mime/types", "testXop");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.mime.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link XopStringType }
     * 
     */
    public XopStringType createXopStringType() {
        return new XopStringType();
    }

    /**
     * Create an instance of {@link XopType }
     * 
     */
    public XopType createXopType() {
        return new XopType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopStringType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXopStringArgument")
    public JAXBElement<XopStringType> createTestXopStringArgument(XopStringType value) {
        return new JAXBElement<XopStringType>(_TestXopStringArgument_QNAME, XopStringType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXopResponse")
    public JAXBElement<XopType> createTestXopResponse(XopType value) {
        return new JAXBElement<XopType>(_TestXopResponse_QNAME, XopType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopStringType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXopStringResponse")
    public JAXBElement<XopStringType> createTestXopStringResponse(XopStringType value) {
        return new JAXBElement<XopStringType>(_TestXopStringResponse_QNAME, XopStringType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XopType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/mime/types", name = "testXop")
    public JAXBElement<XopType> createTestXop(XopType value) {
        return new JAXBElement<XopType>(_TestXop_QNAME, XopType.class, null, value);
    }

}
